@@ -1,7 +1,7 @@
 import numpy as np
 import matplotlib.pyplot as plt
 import h5py
-from .utils import plotJV, getChunk
+from .utils import plotJV, getChunk, getJVparams
 from datetime import datetime
 RTYPES = ["JV","LIGHT","CV","CC","MPP"]
     
@@ -105,15 +105,52 @@ class Result:
         ax.plot(r['t'],r['data'],label=r['name'])
         ax.set_xlabel("Time [min]")
         ax.set_ylabel(f"{r['name']} ({r['unit']})")
-        
-    def getResult(self, sample, pixelID, resultID, includeSensors=False):
+    
+    def getResult(self, sample, pixelID, resultID, includeSensors=False, use_pandas=False, hyst=True):
         s = self.__getSample(sample)['results']
         R = s.get(self.getResultTimestamp(sample, resultID, raw=True))
         if R.attrs["type"]==0: #JV
             data = np.array(R['IV'])
             V = data[pixelID,0,:]
             I = data[pixelID,1,:]
-            return {'type':"JV",'voltage':(V,'V'),'current':(I*1e3,'mA')}
+            params = {"up":{},"down":{}}
+            if hyst:
+                numC = np.sum(np.isnan(V))
+                Vs = [getChunk(V,i) for i in range(numC)]
+                UPs = [v[-1]>v[0] for v in Vs]
+                Is = [getChunk(I,i) for i in range(numC)]
+                iUP = [j for j,u in enumerate(UPs) if u]
+                iDOWN = [j for j,u in enumerate(UPs) if not u]
+                if use_pandas:
+                    import pandas as pd
+                    res = {}
+                    if True in UPs:
+                        res["voltage_up"] = Vs[iUP[0]]
+                        res["current_up"] = Is[iUP[0]]
+                        params["up"] = getJVparams(Vs[iUP[0]],Is[iUP[0]])
+                    if False in UPs:
+                        res["voltage_down"] = Vs[iDOWN[0]]
+                        res["current_down"] = Is[iDOWN[0]]
+                        params["down"] = getJVparams(Vs[iDOWN[0]],Is[iDOWN[0]])
+                    p = list(params.get("up",{}).keys())+list(params.get("down",{}).keys())
+                    p = set(p)
+                    xx = {par:[params.get(x,{}).get(par,np.nan) for x in ["up","down"]] for par in p}
+                    max_length = np.max([len(res[x]) for x in res])
+                    df_params = pd.DataFrame(xx)
+                    df_params.index = ["up","down"]
+                    return pd.DataFrame({x:np.pad(res[x], (0,max_length-len(res[x])), 'constant', constant_values=np.nan) for x in res}), df_params
+                else:
+                    res = {'type':"JV"}
+                    if True in UPs:
+                        res["up"] = {'voltage':Vs[iUP[0]],'current':Is[iUP[0]],'params':getJVparams(Vs[iUP[0]],Is[iUP[0]])}
+                    if False in UPs:
+                        res["down"] = {'voltage':Vs[iDOWN[0]],'current':Is[iDOWN[0]],'params':getJVparams(Vs[iDOWN[0]],Is[iDOWN[0]])}
+                return res
+            else:
+                if use_pandas:
+                    return pd.DataFrame({'voltage':V,'current':I}),getJVparams(V,I)
+                else:
+                    return {'type':"JV",'voltage':V,'current':I,"params":getJVparams(V,I)}
         elif R.attrs["type"] in [2,3,4]:
             t = np.array(R['0']['time'])
             data = np.array(R['0']['data'])
