@@ -10,6 +10,21 @@ def getChunk(data, chunk):
         chunks += [len(data)]
         return data[chunks[chunk]+1:chunks[chunk+1]]
 
+def getJVparams(V,I):
+    MPP = np.min(V*I)
+    impp = np.argmin(V*I)
+    iV = V.argsort()
+    Isc = np.interp(0,V[iV],I[iV])
+    iI = I.argsort()
+    Voc = np.interp(0,I[iI],V[iI])
+    return {
+        "MPP":MPP,
+        "Vmpp":V[impp],
+        "Impp":I[impp],
+        "Voc":Voc,
+        "Isc":Isc,
+        "FF":(I[impp]*V[impp])/(Voc*Isc)}
+    
 def plotJV(res, hyst=True, up=True, down=True, ax=None, **kargs):
     V = res['voltage'][0]
     I = res['current'][0]
